```
__________                                 
 \______   \___.__._____    ____   ______   
  |     ___<   |  |\__  \  /    \ /  ___/   
  |    |    \___  | / __ \|   |  \\___ \    
  |____|    / ____|(____  /___|  /____  >   
            \/          \/     \/     \/    
       /-|                             |-
  -.'.'.-|  Python Console ANSI Viewer |- 
       \-|                             |- 

  PYANS - Python Console ANSI Viewer

  Display ANSI graphics in Your terminal.
  Written in python.

  u, n       - scroll up, down more
  k, j, h, l - scroll up, down, left, right
  $          - display sauce information
  ?          - display help
  a          - autoscroll

```
